#
# spec file for package libunistring
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libunistring
%define lname	libunistring0
Version:        0.9.3
Release:        25.1
Summary:        GNU Unicode string library
License:        LGPL-3.0+ and GPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://www.gnu.org/software/libunistring/
Source0:        libunistring-%{version}.tar.bz2
Source3:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool

# Fix imported gnulib long double math tests for little-endian PowerPC
Patch1:         libunistring-gnulib-ppc64le.patch
# http://lists.openembedded.org/pipermail/openembedded-core/2012-April/059850.html
Patch2:         libunistring-parallel-make.patch

%description
This portable C library implements Unicode string types in three flavours:
(UTF-8, UTF-16, UTF-32), together with functions for character processing
(names, classifications, properties) and functions for string processing
(iteration, formatted output, width, word breaks, line breaks, normalization,
case folding and regular expressions).

%package devel
Summary:        GNU Unicode string library - development files
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       info
# Obsoletes added in 12.2
Obsoletes:      %name < %version-%release
Provides:       %name = %version-%release

%description devel
Development files for programs using libunistring and documentation 
for UniString library.

%package -n %lname
Summary:        GNU Unicode string library - development files
Group:          Development/Libraries/C and C++

%description -n %lname
This portable C library implements Unicode string types in three flavours:
(UTF-8, UTF-16, UTF-32), together with functions for character processing
(names, classifications, properties) and functions for string processing
(iteration, formatted output, width, word breaks, line breaks, normalization,
case folding and regular expressions).


%prep
%setup -q
%patch1 -p1
%patch2

%build
autoreconf -fi
%configure --disable-static --disable-rpath --docdir=%_docdir/%name
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p" install
cp AUTHORS NEWS README HACKING DEPENDENCIES THANKS ChangeLog $RPM_BUILD_ROOT/%{_docdir}/%{name}
rm -f $RPM_BUILD_ROOT/%{_infodir}/dir
rm -f $RPM_BUILD_ROOT/%{_libdir}/libunistring.la

%check
%if ! 0%{?qemu_user_space_build}
make check %{?_smp_mflags}
%endif

%files -n %lname
%defattr(-,root,root)
%{_libdir}/libunistring.so.0*

%files devel
%defattr(-,root,root)
%_docdir/%name
%{_infodir}/libunistring.info*
%{_libdir}/libunistring.so
%{_includedir}/unistring
%{_includedir}/*.h

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/libunistring.info.gz %{_infodir}/dir || :

%preun devel
if [ "$1" = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libunistring.info.gz %{_infodir}/dir || :
fi

%changelog
* Tue Jan  3 2017 mlin@suse.com
- Add baselibs.conf to generate -32bit packages (bsc#1056981)
* Tue Mar  4 2014 pgajdos@suse.com
- fix parallel build
  * added parallel-make.patch [bnc#866723] (private)
* Wed Dec 18 2013 uweigand@de.ibm.com
- libunistring-gnulib-ppc64le.patch: Fix imported gnulib long double
  math tests for little-endian PowerPC.
* Fri Mar 16 2012 cfarrell@suse.com
- license update: LGPL-3.0+ and GPL-3.0+
  Numerous files in tests/ and woedll are GPL-3.0+ licensed. Either put
  them in a separate GPL-3.0+ labelled subpackage or use this label for the
  main License: line
* Sun Mar 11 2012 jengelh@medozas.de
- Nuke unnecessary libunistring binary package: move documentation
  files to devel subpackage
* Mon Jan 30 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Fri Sep 30 2011 crrodriguez@opensuse.org
- Workaround qemu-arm bugs.
* Mon Aug 30 2010 pgajdos@suse.cz
- updated to version 0.9.3:
  * Bug fixes in unistr.h functions:
  - The functions u16_to_u32, u16_to_u8, u8_to_u32, u8_to_u16 now fail when
    the argument is not valid. Previously, they returned a converted string
    where invalid parts were each replaced with U+FFFD.
  - The function u8_mbsnlen now counts an incomplete character at the end
    of the argument string as 1 character. Previously, it could count as 2
    or 3 characters.
  - The return value of the u8_stpncpy, u16_stpncpy, u32_stpncpy functions
    was incorrect.
  - The u8_strcoll, u16_strcoll, u32_strcoll now try harder to give a non-zero
    return value.
* Mon Mar 15 2010 pgajdos@suse.cz
- updated to version 0.9.2.1:
  * The function uc_locale_language now uses the locale of the
    current thread, if a thread-specific locale has been set.
* Tue Nov 24 2009 pgajdos@suse.cz
- initial version of package 0.9.1.1
- spec file taken from
  http://www.pixelbeat.org/patches/libunistring
  (PĂĄdraig Brady <P@draigBrady.com)
- needed by guile 1.9.0 and higher
